1 EfmPointsView

data_handling.EfmPointsView(
    points_world,
    dist_std,
    inv_dist_std,
    time_ns,
    volume_min,
    volume_max,
    lengths,
)

Padded semi-dense SLAM point cloud view with per-frame metadata.

1.1 Attributes

Name Description
points_world Tensor["F N 3", float32] padded world-frame SLAM points (meters).
dist_std Tensor["F N", float32] per-point distance std (depth uncertainty).
inv_dist_std Tensor["F N", float32] per-point inverse distance std.
time_ns Tensor["F", int64] timestamps aligned to point slices.
volume_min Tensor["3", float32] snippet AABB minimum in world coords.
volume_max Tensor["3", float32] snippet AABB maximum in world coords.
lengths Tensor["F", int64] true (unpadded) point counts per frame.

1.2 Methods

Name Description
to Move the semidense point tensors to the requested device and dtype.
collapse_points Collapse points across time and optionally subsample.
last_frame_points_np Return points from the latest frame with valid points, subsampled if needed.

1.2.1 to

data_handling.EfmPointsView.to(device, *, dtype=None)

Move the semidense point tensors to the requested device and dtype.

1.2.2 collapse_points

data_handling.EfmPointsView.collapse_points(
    max_points=None,
    include_inv_dist_std=False,
    include_obs_count=False,
)

Collapse points across time and optionally subsample.

1.2.2.1 Parameters

Name Type Description Default
max_points int | None Optional cap on the number of returned points. None
include_inv_dist_std bool If True, append inverse depth std per point. False
include_obs_count bool If True, append the number of snippet frames that observed each point (observation count). False

1.2.2.2 Returns

Name Type Description
Tensor Tensor["K 3", float32] if no extra features are requested.
Tensor Tensor["K 4", float32] if exactly one extra feature is requested
Tensor (XYZ + inv_dist_std or XYZ + obs_count).
Tensor Tensor["K 5", float32] if both extras are requested
Tensor (XYZ + inv_dist_std + obs_count).

1.2.3 last_frame_points_np

data_handling.EfmPointsView.last_frame_points_np(max_points=None)

Return points from the latest frame with valid points, subsampled if needed.