1 VinOfflineBackboneDiagnostic

data_handling.VinOfflineBackboneDiagnostic(
    field,
    shape,
    numel,
    sampled_rows,
    count,
    mean,
    std,
    abs_mean,
    nz_frac,
)

Streaming numeric summary for one stored backbone field.

1.1 Attributes

Name Description
field Backbone field name without the "backbone." prefix.
shape Per-row tensor shape.
numel Number of elements per sampled row.
sampled_rows Number of rows contributing to the summary.
count Number of finite elements contributing to summary moments.
mean Mean finite value.
std Population standard deviation for finite values.
abs_mean Mean absolute finite value.
nz_frac Fraction of finite values whose absolute value is larger than 1e-6.