1 EfmCameraView
data_handling.efm_views.EfmCameraView(
images,
calib,
time_ns,
frame_ids,
distance_m=None,
distance_time_ns=None,
)Zero-copy camera stream view in EFM schema (images, calibration, timing, optional depth).
1.1 Attributes
| Name | Description |
|---|---|
| images | Tensor["F C H W", float32] normalized camera images in Aria LUF frame. |
| calib | Per-frame camera intrinsics/extrinsics (CameraTW.tensor shape (F,34)). |
| time_ns | Tensor["F", int64] device timestamps aligned to images. |
| frame_ids | Tensor["F", int64\|float32] frame ids within the snippet. |
| distance_m | Optional metric ray distances Tensor["F 1 H W", float32]. |
| distance_time_ns | Optional Tensor["F", int64] timestamps for distance_m. |
| num_frames | Return the number of frames in the camera stream. |
1.2 Methods
| Name | Description |
|---|---|
| to | Move the camera view tensors to the requested device and dtype. |
| get_fov | Tensor[“F 2”, float32] FOV in degrees (fov_x, fov_y) per frame. |
| select_frame_indices | Resolve user-provided frame indices, supporting negatives and defaults. |
| nearest_traj_indices | Return selected camera indices and nearest trajectory indices. |
1.2.1 to
data_handling.efm_views.EfmCameraView.to(device, *, dtype=None)Move the camera view tensors to the requested device and dtype.
1.2.2 get_fov
data_handling.efm_views.EfmCameraView.get_fov()Tensor[“F 2”, float32] FOV in degrees (fov_x, fov_y) per frame.
1.2.3 select_frame_indices
data_handling.efm_views.EfmCameraView.select_frame_indices(
frame_indices,
*,
default_last,
)Resolve user-provided frame indices, supporting negatives and defaults.
1.2.4 nearest_traj_indices
data_handling.efm_views.EfmCameraView.nearest_traj_indices(
traj_ts_ns,
frame_indices=None,
*,
default_last=True,
)Return selected camera indices and nearest trajectory indices.