Return the stable integer provenance id for a position family.
Source Code
# candidate_position_id { #aria_nbv.pose_generation.candidate_mixture.candidate_position_id }```pythonpose_generation.candidate_mixture.candidate_position_id(position_mode)```Return the stable integer provenance id for a position family.