Return the stable integer provenance id for a view-direction family.
Source Code
# candidate_strategy_id { #aria_nbv.pose_generation.candidate_mixture.candidate_strategy_id }```pythonpose_generation.candidate_mixture.candidate_strategy_id(strategy)```Return the stable integer provenance id for a view-direction family.