Convert stacked depth maps into batched point clouds and fuse with SLAM.
Source Code
# build_candidate_pointclouds { #aria_nbv.rendering.build_candidate_pointclouds }```pythonrendering.build_candidate_pointclouds(sample, batch, *, stride=1)```Convert stacked depth maps into batched point clouds and fuse with SLAM.