1 CandidateDepthRenderer

rendering.candidate_depth_renderer.CandidateDepthRenderer(config)

High-level wrapper that renders depth for compact valid candidate poses.

1.1 Methods

Name Description
render Render depth maps for valid candidate poses within a snippet.
render_compact_indices Render depth maps for explicit compact-valid candidate rows.

1.1.1 render

rendering.candidate_depth_renderer.CandidateDepthRenderer.render(
    sample,
    candidates,
)

Render depth maps for valid candidate poses within a snippet.

1.1.2 render_compact_indices

rendering.candidate_depth_renderer.CandidateDepthRenderer.render_compact_indices(
    sample,
    candidates,
    compact_indices,
)

Render depth maps for explicit compact-valid candidate rows.

1.1.2.1 Parameters

Name Type Description Default
sample EfmSnippetView Snippet with an attached mesh. required
candidates CandidateSamplingResult Full candidate sampling result. required
compact_indices torch.Tensor | list[int] | tuple[int, …] Row indices into candidates.views. These are compact valid-candidate indices, not full-shell indices. required

1.1.2.2 Returns

Name Type Description
CandidateDepths Rendered depth batch aligned with compact_indices and carrying
CandidateDepths full-shell candidate_indices for joins.