1 build_candidate_pointclouds
rendering.candidate_pointclouds.build_candidate_pointclouds(
sample,
batch,
*,
stride=1,
)Convert stacked depth maps into batched point clouds and fuse with SLAM.
Convert stacked depth maps into batched point clouds and fuse with SLAM.