rollouts.ROLLOUT_ZARR_SCHEMA_ID
Schema id stored as a root attribute on rollout replay stores.
# ROLLOUT_ZARR_SCHEMA_ID { #aria_nbv.rollouts.ROLLOUT_ZARR_SCHEMA_ID } `rollouts.ROLLOUT_ZARR_SCHEMA_ID` Schema id stored as a root attribute on rollout replay stores.