1 RolloutShardRow

rollouts.RolloutShardRow(
    order,
    sample_index,
    sample_key,
    scene_id,
    snippet_id,
    split,
    source_shard_id,
    source_shard_row,
)

One VIN offline source row owned by a rollout shard.

1.1 Methods

Name Description
from_index_record Build a manifest row from a VIN offline index record.
from_jsonable Decode one JSON row payload.
to_jsonable Return a stable JSON-compatible row payload.
hash_record Return the row fields used for deterministic lineage hashing.
matches_record Return whether a VIN offline index record matches this manifest row.

1.1.1 from_index_record

rollouts.RolloutShardRow.from_index_record(record, *, order)

Build a manifest row from a VIN offline index record.

1.1.2 from_jsonable

rollouts.RolloutShardRow.from_jsonable(payload)

Decode one JSON row payload.

1.1.3 to_jsonable

rollouts.RolloutShardRow.to_jsonable()

Return a stable JSON-compatible row payload.

1.1.4 hash_record

rollouts.RolloutShardRow.hash_record()

Return the row fields used for deterministic lineage hashing.

1.1.5 matches_record

rollouts.RolloutShardRow.matches_record(record)

Return whether a VIN offline index record matches this manifest row.