rollouts.rollout_store_inventory_rows(store_paths)
Return schema, validation, count, lineage, and storage rows for stores.
# rollout_store_inventory_rows { #aria_nbv.rollouts.rollout_store_inventory_rows } ```python rollouts.rollout_store_inventory_rows(store_paths) ``` Return schema, validation, count, lineage, and storage rows for stores.