Validate a standalone rollout replay store and return all discovered errors.
Source Code
# validate_rollout_zarr_store { #aria_nbv.rollouts.validate_rollout_zarr_store }```pythonrollouts.validate_rollout_zarr_store(store_dir)```Validate a standalone rollout replay store and return all discovered errors.