Schema id stored as a root attribute on rollout replay stores.
Source Code
# ROLLOUT_ZARR_SCHEMA_ID { #aria_nbv.rollouts.zarr_store.ROLLOUT_ZARR_SCHEMA_ID }`rollouts.zarr_store.ROLLOUT_ZARR_SCHEMA_ID`Schema id stored as a root attribute on rollout replay stores.