1 TargetConfig

utils.TargetConfig()

Typed config-as-factory base whose setup_target returns TargetT.

TargetT describes the runtime object returned by setup_target; it does not have to be the same type as target_type when the target delegates to a custom factory method.

1.1 Methods

Name Description
setup_target Instantiate or return the typed target object for this config.

1.1.1 setup_target

utils.TargetConfig.setup_target(*args, **kwargs)

Instantiate or return the typed target object for this config.