Check if a scene has the expected mesh and ATEK shards.
1.1 Parameters
Name
Type
Description
Default
scene_id
str
Scene identifier.
required
data_dir
Path
Root data directory containing ase_meshes and ase_atek.
required
require_mesh
bool
Raise FileNotFoundError when the mesh is missing.
False
require_atek
bool
Raise FileNotFoundError when ATEK shards are missing.
False
1.2 Returns
Name
Type
Description
dict[str, bool | Path | None]
Dictionary with existence flags and resolved paths.
Source Code
# validate_scene_data { #aria_nbv.utils.validate_scene_data }```pythonutils.validate_scene_data( scene_id, data_dir, require_mesh=False, require_atek=False,)```Check if a scene has the expected mesh and ATEK shards.## Parameters {.doc-section .doc-section-parameters}| Name | Type | Description | Default ||--------------|--------|-----------------------------------------------------------------|------------|| scene_id | str | Scene identifier. | _required_ || data_dir | Path | Root data directory containing ``ase_meshes`` and ``ase_atek``. | _required_ || require_mesh | bool | Raise ``FileNotFoundError`` when the mesh is missing. | `False` || require_atek | bool | Raise ``FileNotFoundError`` when ATEK shards are missing. | `False` |## Returns {.doc-section .doc-section-returns}| Name | Type | Description ||--------|-----------------------------------|-----------------------------------------------------||| dict\[str, bool \| Path \| None\]| Dictionary with existence flags and resolved paths. |