1 LearnableFourierFeatures

vin.pose_encoding.LearnableFourierFeatures(config)

Learnable Fourier Features (LFF) positional encoding.

This module maps continuous inputs \(x \in \mathbb{R}^D\) into a learned feature space by:

  1. learning a projection matrix \(W_r\),
  2. applying sinusoidal features, and
  3. mapping them through a small MLP.

Compared to fixed random Fourier features, the learned projection and the MLP allow the encoding to adapt to the downstream task.

1.1 Methods

Name Description
forward TODO: Ensure same signature as other pose encoders - i.e. ShellShPoseEncoder.forward (derive both from a common base class!)

1.1.1 forward

vin.pose_encoding.LearnableFourierFeatures.forward(x)

TODO: Ensure same signature as other pose encoders - i.e. ShellShPoseEncoder.forward (derive both from a common base class!)