1 EfmTrajectoryView
data_handling.efm_views.EfmTrajectoryView(
t_world_rig,
time_ns,
gravity_in_world,
)World-frame rig trajectory aligned to snippet frames.
1.1 Attributes
| Name | Description |
|---|---|
| t_world_rig | Rig SE(3) poses per frame (world←rig). |
| time_ns | Tensor["F", int64] pose timestamps. |
| gravity_in_world | Tensor["3", float32] gravity vector in world frame (aligned to [0,0,-9.81]). |
| final_pose | Final rig pose in snippet. world ← rig. |
1.2 Methods
| Name | Description |
|---|---|
| to | Move the trajectory tensors to the requested device and dtype. |
1.2.1 to
data_handling.efm_views.EfmTrajectoryView.to(device, *, dtype=None)Move the trajectory tensors to the requested device and dtype.