1 RolloutSuspiciousQueryConfig
rollouts.RolloutSuspiciousQueryConfig(
min_valid_candidates=3,
dominant_invalid_fraction=0.8,
high_target_score=0.5,
max_step_distance_m=1.25,
max_height_delta_m=0.6,
max_backward_step_m=0.35,
max_yaw_delta_deg=85.0,
)Thresholds used by suspicious_rollout_rows.
1.1 Attributes
| Name | Description |
|---|---|
| min_valid_candidates | Flag steps with fewer actor-valid candidates than this count. |
| dominant_invalid_fraction | Flag a step when one invalid reason explains at least this fraction of invalid rows. |
| high_target_score | Flag invalid GT target rows whose selection score is at least this value. |
| max_step_distance_m | Motion-realism threshold for selected candidate step length. |
| max_height_delta_m | Motion-realism threshold for selected candidate height delta. |
| max_backward_step_m | Motion-realism threshold for selected candidate backward motion. |
| max_yaw_delta_deg | Motion-realism threshold for selected candidate yaw delta. |