1 discover_rollout_store_paths
rollouts.discover_rollout_store_paths(base_dir, *, pattern='**/*.zarr')Return rollout Zarr store candidates under a cache directory.
1.1 Parameters
| Name | Type | Description | Default |
|---|---|---|---|
| base_dir | Path | Directory to scan recursively. | required |
| pattern | str | Glob pattern used to find Zarr directories. | '**/*.zarr' |
1.2 Returns
| Name | Type | Description |
|---|---|---|
| list[Path] | Absolute store paths sorted with the newest candidates first. |