1 RolloutZarrStoreConfig
rollouts.zarr_store.RolloutZarrStoreConfig()Filesystem and target metadata for one standalone rollout replay store.
1.1 Attributes
| Name | Description |
|---|---|
| q_h_chunk_states | Number of state rows per chunk in the persisted derived q_h/ view. |
| target_eval_crop_max_points | Fixed row width for oracle/eval target crop point payloads. |
| target_eval_crops_enabled | Persist oracle/eval target crop point payloads for sampled audit shards. |